@@ -136,7 +136,10 @@ GExiv2Metadata* gexiv2_metadata_new					(void);
  * gexiv2_metadata_free:
  *
  * Destroys the #GExiv2Metadata object and frees all associated memory.
+ *
+ * Deprecated: 0.10.3: Use g_object_unref() instread.
  */
+G_DEPRECATED_FOR(g_object_unref)
 void			gexiv2_metadata_free				(GExiv2Metadata *self);
 
 /**
@@ -161,7 +164,7 @@ gboolean		gexiv2_metadata_open_path			(GExiv2Metadata *self, const gchar *path,
 gboolean		gexiv2_metadata_open_buf			(GExiv2Metadata *self, const guint8 *data, glong n_data, GError **error);
 
 /**
- * gexiv2_metadata_open_stream:
+ * gexiv2_metadata_open_stream: (skip)
  * @cb: A #ManagedStreamCallbacks struct offering stream access.
  *
  * The stream must be an image format supported by Exiv2.
@@ -193,7 +196,7 @@ gboolean		gexiv2_metadata_from_app1_segment	(GExiv2Metadata *self, const guint8
 gboolean		gexiv2_metadata_save_file			(GExiv2Metadata *self, const gchar *path, GError **error);
 
 /**
- * gexiv2_metadata_save_stream:
+ * gexiv2_metadata_save_stream: (skip)
  * @cb: A #ManagedStreamCallbacks struct offering stream access.
  *
  * Saves the metadata to the stream by reading the stream into memory,copying this object's
@@ -424,7 +427,7 @@ gchar**			gexiv2_metadata_get_tag_multiple	(GExiv2Metadata *self, const gchar* t
  *
  * The Exiv2 Tag Reference can be found at http://exiv2.org/metadata.html
  *
- * Returns: (transfer full): Boolean success value
+ * Returns: Boolean success value
  */
 gboolean		gexiv2_metadata_set_tag_multiple	(GExiv2Metadata *self, const gchar* tag, const gchar** values);
 
@@ -438,7 +441,7 @@ gboolean		gexiv2_metadata_set_tag_multiple	(GExiv2Metadata *self, const gchar* t
  */
 GBytes*			gexiv2_metadata_get_tag_raw			(GExiv2Metadata *self, const gchar* tag);
 
-/**
+/*
  * EXIF functions
  */
 
@@ -518,7 +521,7 @@ void			gexiv2_metadata_set_exif_thumbnail_from_buffer (GExiv2Metadata *self, con
 void			gexiv2_metadata_erase_exif_thumbnail (GExiv2Metadata *self);
 
 
-/**
+/*
  * XMP functions
  */
 
@@ -602,7 +605,7 @@ void			gexiv2_metadata_clear_iptc			(GExiv2Metadata *self);
  */
 gchar**			gexiv2_metadata_get_iptc_tags		(GExiv2Metadata *self);
 
-/**
+/*
  * Composite getters/setters and helpful functions.
  */
 
@@ -621,19 +624,30 @@ GExiv2Orientation gexiv2_metadata_get_orientation 	(GExiv2Metadata *self);
  */
 void			gexiv2_metadata_set_orientation		(GExiv2Metadata *self, GExiv2Orientation orientation);
 
+gint gexiv2_metadata_get_metadata_pixel_width (GExiv2Metadata *self);
+gint gexiv2_metadata_get_metadata_pixel_height (GExiv2Metadata *self);
+void gexiv2_metadata_set_metadata_pixel_width (GExiv2Metadata *self, gint width);
+void gexiv2_metadata_set_metadata_pixel_height (GExiv2Metadata *self, gint height);
+
 /**
  * gexiv2_metadata_get_comment:
  *
  * A composite accessor that uses the first available metadata field from a list of well-known
- * locations to find the photo's comment (or description).  These fields are:
+ * locations to find the photo's comment (or description).  
  *
- * Exif.Image.ImageDescription
+ * MWG guidelines refer to these as <em>Description</em>: a textual description of a resource's content.
+ * 
+ * These fields are:
+ *
+ * Exif.Image.ImageDescription  (MWG Guidelines)
  * Exif.Photo.UserComment
  * Exif.Image.XPComment
- * Iptc.Application2.Caption
+ * Iptc.Application2.Caption    (MWG Guidelines)
+ * Xmp.dc.description           (MWG Guidelines)
+ * Xmp.acdsee.notes             (Commonly requested, read only)
  *
- * Note that Exif.Image.ImageDescription is <em>not</em> technically a description field and is
- * described in the EXIF specification as "the title of the image".  Also, it does not support
+ * Note that in the EXIF specification Exif.Image.ImageDescription is 
+ * described  as "the title of the image".  Also, it does not support
  * two-byte character codes for encoding.  However, it's still used here for legacy reasons.
  *
  * For fine-grained control, it's recommened to use Exiv2 tags directly rather than this method,
@@ -699,7 +713,7 @@ gdouble			gexiv2_metadata_get_focal_length	(GExiv2Metadata *self);
  */
 gint			gexiv2_metadata_get_iso_speed		(GExiv2Metadata *self);
 
-/**
+/*
  * GPS functions
  */
 
@@ -754,7 +768,7 @@ gboolean		gexiv2_metadata_set_gps_info				(GExiv2Metadata *self, gdouble longitu
  */
 void			gexiv2_metadata_delete_gps_info			(GExiv2Metadata *self);
 
-/**
+/*
  * Preview Manager
  */
 
